pub enum WorkerFrame {
Descriptor {
protocol_version: u16,
descriptor: WorkerDescriptor,
},
Health {
protocol_version: u16,
health: WorkerHealth,
},
Accepted {
protocol_version: u16,
run_id: RunId,
},
Event {
protocol_version: u16,
envelope: RuntimeEventEnvelope,
},
ControlAcknowledged {
protocol_version: u16,
run_id: RunId,
},
Result {
protocol_version: u16,
result: RunResult,
},
Error {
protocol_version: u16,
run_id: Option<RunId>,
error: RuntimeError,
},
}Expand description
Frames returned by a Worker transport. Events and the terminal result may be streamed over WebSocket/SSE or represented by repeated polling without changing their JSON shape.
Variants
Implementations
Sourceimpl WorkerFrame
impl WorkerFrame
pub fn protocol_version(&self) -> u16
pub fn validate_protocol(&self) -> Result<(), RuntimeError>